@@ -37,12 +37,12 @@
 #include <QtCore/QList>
 #include <QtCore/QPluginLoader>
 #include <QtCore/QPointer>
+#include <QtCore/QSettings>
 #ifndef PHONON_NO_DBUS
 #include <QtDBus/QtDBus>
 #endif
 #include <QApplication>
 #include <QMessageBox>
-
 namespace Phonon
 {
 
@@ -525,6 +525,7 @@ PlatformPlugin *FactoryPrivate::platformPlugin()
             }
             const QStringList files = dir.entryList(QDir::Files);
             for (int i = 0; i < files.count(); ++i) {
+                pDebug() << "attempting to load" << libPath + files.at(i);
                 QPluginLoader pluginLoader(libPath + files.at(i));
                 if (!pluginLoader.load()) {
                     pDebug() << Q_FUNC_INFO << "  platform plugin load failed:"
